Modules
Structs
Concurrently upload a Stream/File to an Azure Blob Store using a SAS URL.
Enums
Constants
Azure’s default max request rate for a storage account is 20,000 per second.
By keeping to 10 or fewer concurrent upload threads, AVML can be used to
simultaneously upload images from 1000 different hosts concurrently (a full
VM scaleset) to a single default storage account.
Functions
Upload a file via HTTP PUT